Reviewed-by: Qiu Shumin <[email protected]>

-----Original Message-----
From: Long, Qin 
Sent: Monday, November 23, 2015 4:39 PM
To: [email protected]
Cc: Qiu, Shumin
Subject: [Patch] [CryptoPkg] Correct one typo in the API comments.

Correct one typo (SingerChainCerts --> SignerChainCerts) in the comments for 
Pkcs7GetCertificatesList() API.

Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Qin Long <[email protected]>
CC: Shumin Qiu <[email protected]>
---
 CryptoPkg/Include/Library/BaseCryptLib.h                              | 2 +-
 CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7Verify.c                  | 4 ++--
 CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7VerifyNull.c              | 2 +-
 .../BaseCryptLibRuntimeCryptProtocol/Pk/CryptPkcs7VerifyNull.c        | 2 +-
 4 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/CryptoPkg/Include/Library/BaseCryptLib.h 
b/CryptoPkg/Include/Library/BaseCryptLib.h
index 390e302..0371d73 100644
--- a/CryptoPkg/Include/Library/BaseCryptLib.h
+++ b/CryptoPkg/Include/Library/BaseCryptLib.h
@@ -1992,7 +1992,7 @@ Pkcs7FreeSigners (
 
   @param[in]  P7Data            Pointer to the PKCS#7 message.
   @param[in]  P7Length          Length of the PKCS#7 message in bytes.
-  @param[out] SingerChainCerts  Pointer to the certificates list chained to 
signer's
+  @param[out] SignerChainCerts  Pointer to the certificates list 
+ chained to signer's
                                 certificate. It's caller's responsiblity to 
free the buffer.
   @param[out] ChainLength       Length of the chained certificates list buffer 
in bytes.
   @param[out] UnchainCerts      Pointer to the unchained certificates lists. 
It's caller's
--- a/CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7VerifyNull.c
+++ b/CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7VerifyNull.c
@@ -74,7 +74,7 @@ Pkcs7FreeSigners (
 
   @param[in]  P7Data            Pointer to the PKCS#7 message.
   @param[in]  P7Length          Length of the PKCS#7 message in bytes.
-  @param[out] SingerChainCerts  Pointer to the certificates list chained to 
signer's
+  @param[out] SignerChainCerts  Pointer to the certificates list 
+ chained to signer's
                                 certificate. It's caller's responsiblity to 
free the buffer.
   @param[out] ChainLength       Length of the chained certificates list buffer 
in bytes.
   @param[out] UnchainCerts      Pointer to the unchained certificates lists. 
It's caller's
diff --git a/CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7Verify.c 
b/CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7Verify.c
index 6a84137..559610d 100644
--- a/CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7Verify.c
+++ b/CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7Verify.c
@@ -435,7 +435,7 @@ Pkcs7FreeSigners (
 
   @param[in]  P7Data            Pointer to the PKCS#7 message.
   @param[in]  P7Length          Length of the PKCS#7 message in bytes.
-  @param[out] SingerChainCerts  Pointer to the certificates list chained to 
signer's
+  @param[out] SignerChainCerts  Pointer to the certificates list 
+ chained to signer's
                                 certificate. It's caller's responsiblity to 
free the buffer.
   @param[out] ChainLength       Length of the chained certificates list buffer 
in bytes.
   @param[out] UnchainCerts      Pointer to the unchained certificates lists. 
It's caller's
@@ -521,7 +521,7 @@ Pkcs7GetCertificatesList (
   //
   // Obtains Signer's Certificate from PKCS#7 data
   // NOTE: Only one signer case will be handled in this function, which means 
SignerInfos
   //       should include only one singer's certificate.
   //
   Signers = PKCS7_get0_signers (Pkcs7, NULL, PKCS7_BINARY);
   if ((Signers == NULL) || (sk_X509_num (Signers) != 1)) { diff --git 
@@ -521,7 +521,7 @@ Pkcs7GetCertificatesList (
   // NOTE: Only one signer case will be handled in this function, which means 
SignerInfos
-  //       should include only one singer's certificate.
+  //       should include only one signer's certificate.
   //
   Signers = PKCS7_get0_signers (Pkcs7, NULL, PKCS7_BINARY);
a/CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7VerifyNull.c 
b/CryptoPkg/Library/BaseCryptLib/Pk/CryptPkcs7VerifyNull.c
index b9affe4..05433ff 100644
diff --git 
a/CryptoPkg/Library/BaseCryptLibRuntimeCryptProtocol/Pk/CryptPkcs7VerifyNull.c 
b/CryptoPkg/Library/BaseCryptLibRuntimeCryptProtocol/Pk/CryptPkcs7VerifyNull.c
index b9affe4..05433ff 100644
--- 
a/CryptoPkg/Library/BaseCryptLibRuntimeCryptProtocol/Pk/CryptPkcs7VerifyNull.c
+++ b/CryptoPkg/Library/BaseCryptLibRuntimeCryptProtocol/Pk/CryptPkcs7Ve
+++ rifyNull.c
@@ -74,7 +74,7 @@ Pkcs7FreeSigners (
 
   @param[in]  P7Data            Pointer to the PKCS#7 message.
   @param[in]  P7Length          Length of the PKCS#7 message in bytes.
-  @param[out] SingerChainCerts  Pointer to the certificates list chained to 
signer's
+  @param[out] SignerChainCerts  Pointer to the certificates list 
+ chained to signer's
                                 certificate. It's caller's responsiblity to 
free the buffer.
   @param[out] ChainLength       Length of the chained certificates list buffer 
in bytes.
   @param[out] UnchainCerts      Pointer to the unchained certificates lists. 
It's caller's
--
2.5.1.windows.1

_______________________________________________
edk2-devel mailing list
[email protected]
https://lists.01.org/mailman/listinfo/edk2-devel

Reply via email to